# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.14-v202401222359
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableDefinitionInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_definitions': 'list[ColumnDefinitionInputV1]',
        'data_id': 'str',
        'datasource_class': 'str',
        'datasource_id': 'str',
        'description': 'str',
        'name': 'str',
        'scoped_to': 'str',
        'subscription_id': 'str'
    }

    attribute_map = {
        'column_definitions': 'columnDefinitions',
        'data_id': 'dataId',
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'description': 'description',
        'name': 'name',
        'scoped_to': 'scopedTo',
        'subscription_id': 'subscriptionId'
    }

    def __init__(self, column_definitions=None, data_id=None, datasource_class=None, datasource_id=None, description=None, name=None, scoped_to=None, subscription_id=None):
        """
        TableDefinitionInputV1 - a model defined in Swagger
        """

        self._column_definitions = None
        self._data_id = None
        self._datasource_class = None
        self._datasource_id = None
        self._description = None
        self._name = None
        self._scoped_to = None
        self._subscription_id = None

        if column_definitions is not None:
          self.column_definitions = column_definitions
        if data_id is not None:
          self.data_id = data_id
        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if description is not None:
          self.description = description
        if name is not None:
          self.name = name
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if subscription_id is not None:
          self.subscription_id = subscription_id

    @property
    def column_definitions(self):
        """
        Gets the column_definitions of this TableDefinitionInputV1.
        Column definitions for the Table. A column definition contains all the properties that define each column in the table. An \"item id\" column is required and must reference a Seeq item (e.g. Condition ID). A \"datum id\" column is required because it is used to uniquely identify a row (e.g. Capsule Start property).

        :return: The column_definitions of this TableDefinitionInputV1.
        :rtype: list[ColumnDefinitionInputV1]
        """
        return self._column_definitions

    @column_definitions.setter
    def column_definitions(self, column_definitions):
        """
        Sets the column_definitions of this TableDefinitionInputV1.
        Column definitions for the Table. A column definition contains all the properties that define each column in the table. An \"item id\" column is required and must reference a Seeq item (e.g. Condition ID). A \"datum id\" column is required because it is used to uniquely identify a row (e.g. Capsule Start property).

        :param column_definitions: The column_definitions of this TableDefinitionInputV1.
        :type: list[ColumnDefinitionInputV1]
        """
        if column_definitions is None:
            raise ValueError("Invalid value for `column_definitions`, must not be `None`")

        self._column_definitions = column_definitions

    @property
    def data_id(self):
        """
        Gets the data_id of this TableDefinitionInputV1.
        A unique identifier for the table definition within its datasource

        :return: The data_id of this TableDefinitionInputV1.
        :rtype: str
        """
        return self._data_id

    @data_id.setter
    def data_id(self, data_id):
        """
        Sets the data_id of this TableDefinitionInputV1.
        A unique identifier for the table definition within its datasource

        :param data_id: The data_id of this TableDefinitionInputV1.
        :type: str
        """

        self._data_id = data_id

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this TableDefinitionInputV1.
        Along with the Datasource ID, the Datasource Class uniquely identifies a datasource

        :return: The datasource_class of this TableDefinitionInputV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this TableDefinitionInputV1.
        Along with the Datasource ID, the Datasource Class uniquely identifies a datasource

        :param datasource_class: The datasource_class of this TableDefinitionInputV1.
        :type: str
        """

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this TableDefinitionInputV1.
        Along with the Datasource Class, the Datasource ID uniquely identifies a datasource

        :return: The datasource_id of this TableDefinitionInputV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this TableDefinitionInputV1.
        Along with the Datasource Class, the Datasource ID uniquely identifies a datasource

        :param datasource_id: The datasource_id of this TableDefinitionInputV1.
        :type: str
        """

        self._datasource_id = datasource_id

    @property
    def description(self):
        """
        Gets the description of this TableDefinitionInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this TableDefinitionInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TableDefinitionInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this TableDefinitionInputV1.
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """
        Gets the name of this TableDefinitionInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this TableDefinitionInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TableDefinitionInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this TableDefinitionInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this TableDefinitionInputV1.
        The ID of the workbook to which the table definition will be scoped. If not provided, the table definition will have a global scope

        :return: The scoped_to of this TableDefinitionInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this TableDefinitionInputV1.
        The ID of the workbook to which the table definition will be scoped. If not provided, the table definition will have a global scope

        :param scoped_to: The scoped_to of this TableDefinitionInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def subscription_id(self):
        """
        Gets the subscription_id of this TableDefinitionInputV1.
        The ID of the item (only condition monitors supported for now) to subscribe to.

        :return: The subscription_id of this TableDefinitionInputV1.
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """
        Sets the subscription_id of this TableDefinitionInputV1.
        The ID of the item (only condition monitors supported for now) to subscribe to.

        :param subscription_id: The subscription_id of this TableDefinitionInputV1.
        :type: str
        """

        self._subscription_id = subscription_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableDefinitionInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
