# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 62.0.14-v202401222359
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConnectorOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_name': 'str',
        'backups': 'list[JsonBackupOutputV1]',
        'created_at': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'json': 'str',
        'name': 'str',
        'propagation_pending': 'bool',
        'status_message': 'str',
        'translation_key': 'str',
        'type': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'agent_name': 'agentName',
        'backups': 'backups',
        'created_at': 'createdAt',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'json': 'json',
        'name': 'name',
        'propagation_pending': 'propagationPending',
        'status_message': 'statusMessage',
        'translation_key': 'translationKey',
        'type': 'type',
        'updated_at': 'updatedAt'
    }

    def __init__(self, agent_name=None, backups=None, created_at=None, description=None, effective_permissions=None, id=None, is_archived=False, is_redacted=False, json=None, name=None, propagation_pending=False, status_message=None, translation_key=None, type=None, updated_at=None):
        """
        ConnectorOutputV1 - a model defined in Swagger
        """

        self._agent_name = None
        self._backups = None
        self._created_at = None
        self._description = None
        self._effective_permissions = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._json = None
        self._name = None
        self._propagation_pending = None
        self._status_message = None
        self._translation_key = None
        self._type = None
        self._updated_at = None

        if agent_name is not None:
          self.agent_name = agent_name
        if backups is not None:
          self.backups = backups
        if created_at is not None:
          self.created_at = created_at
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if json is not None:
          self.json = json
        if name is not None:
          self.name = name
        if propagation_pending is not None:
          self.propagation_pending = propagation_pending
        if status_message is not None:
          self.status_message = status_message
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def agent_name(self):
        """
        Gets the agent_name of this ConnectorOutputV1.
        The name of the agent.

        :return: The agent_name of this ConnectorOutputV1.
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """
        Sets the agent_name of this ConnectorOutputV1.
        The name of the agent.

        :param agent_name: The agent_name of this ConnectorOutputV1.
        :type: str
        """

        self._agent_name = agent_name

    @property
    def backups(self):
        """
        Gets the backups of this ConnectorOutputV1.
        The list of backups for this object's json property.

        :return: The backups of this ConnectorOutputV1.
        :rtype: list[JsonBackupOutputV1]
        """
        return self._backups

    @backups.setter
    def backups(self, backups):
        """
        Sets the backups of this ConnectorOutputV1.
        The list of backups for this object's json property.

        :param backups: The backups of this ConnectorOutputV1.
        :type: list[JsonBackupOutputV1]
        """

        self._backups = backups

    @property
    def created_at(self):
        """
        Gets the created_at of this ConnectorOutputV1.
        The ISO 8601 date of when the object was created (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm).

        :return: The created_at of this ConnectorOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ConnectorOutputV1.
        The ISO 8601 date of when the object was created (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm).

        :param created_at: The created_at of this ConnectorOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def description(self):
        """
        Gets the description of this ConnectorOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this ConnectorOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConnectorOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this ConnectorOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this ConnectorOutputV1.

        :return: The effective_permissions of this ConnectorOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this ConnectorOutputV1.

        :param effective_permissions: The effective_permissions of this ConnectorOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def id(self):
        """
        Gets the id of this ConnectorOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this ConnectorOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConnectorOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this ConnectorOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this ConnectorOutputV1.
        Whether item is archived

        :return: The is_archived of this ConnectorOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this ConnectorOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this ConnectorOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this ConnectorOutputV1.
        Whether item is redacted

        :return: The is_redacted of this ConnectorOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this ConnectorOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this ConnectorOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def json(self):
        """
        Gets the json of this ConnectorOutputV1.
        The connector's configuration json.

        :return: The json of this ConnectorOutputV1.
        :rtype: str
        """
        return self._json

    @json.setter
    def json(self, json):
        """
        Sets the json of this ConnectorOutputV1.
        The connector's configuration json.

        :param json: The json of this ConnectorOutputV1.
        :type: str
        """

        self._json = json

    @property
    def name(self):
        """
        Gets the name of this ConnectorOutputV1.
        The human readable name

        :return: The name of this ConnectorOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConnectorOutputV1.
        The human readable name

        :param name: The name of this ConnectorOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def propagation_pending(self):
        """
        Gets the propagation_pending of this ConnectorOutputV1.
        Whether the configuration change propagation is pending.

        :return: The propagation_pending of this ConnectorOutputV1.
        :rtype: bool
        """
        return self._propagation_pending

    @propagation_pending.setter
    def propagation_pending(self, propagation_pending):
        """
        Sets the propagation_pending of this ConnectorOutputV1.
        Whether the configuration change propagation is pending.

        :param propagation_pending: The propagation_pending of this ConnectorOutputV1.
        :type: bool
        """

        self._propagation_pending = propagation_pending

    @property
    def status_message(self):
        """
        Gets the status_message of this ConnectorOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this ConnectorOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ConnectorOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this ConnectorOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def translation_key(self):
        """
        Gets the translation_key of this ConnectorOutputV1.
        The item's translation key, if any

        :return: The translation_key of this ConnectorOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this ConnectorOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this ConnectorOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this ConnectorOutputV1.
        The type of the item

        :return: The type of this ConnectorOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ConnectorOutputV1.
        The type of the item

        :param type: The type of this ConnectorOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def updated_at(self):
        """
        Gets the updated_at of this ConnectorOutputV1.
        The ISO 8601 date of when the object was updated (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm).

        :return: The updated_at of this ConnectorOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this ConnectorOutputV1.
        The ISO 8601 date of when the object was updated (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm).

        :param updated_at: The updated_at of this ConnectorOutputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConnectorOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
